Parser

Struct Parser 

pub struct Parser<'a> {
    pub lexer: Lexer<'a>,
    pub source: &'a str,
    pub current: Token,
    pub arena: AstArena,
    /* private fields */
}

Fields

lexer: Lexer<'a>source: &'a strcurrent: Tokenarena: AstArena

Implementations

Source

impl<'a> Parser<'a>

pub fn parse_expression(&mut self) -> Option<ExprId>

Parse an expression

pub fn parse_assignment(&mut self, expr: ExprId) -> Option<ExprId>

Source

impl<'a> Parser<'a>

pub fn new(lexer: Lexer<'a>, source: &'a str) -> Self

pub fn bump(&mut self)

Move to the next token

pub fn peek(&self) -> TokenKind

Peek at the current token without consuming it

pub fn peek_n(&mut self, n: usize) -> TokenKind

Peek ahead by n tokens without consuming them.

pub fn ident_text(&self) -> SharedString

Get identifier text from current token

pub fn is(&self, kind: TokenKind) -> bool

Check if current token is of given kind

pub fn expect(&mut self, kind: TokenKind) -> Span

Expect a specific token, consume it and return its span

pub fn consume(&mut self, kind: TokenKind) -> bool

Consume if current token matches, return true if consumed

pub fn parse_compilation_unit(self) -> ParseResult

pub fn parse_type(&mut self) -> Option<AstTypeId>

pub fn parse_type_without_array_suffix(&mut self) -> Option<AstTypeId>

Source

impl<'a> Parser<'a>

pub fn parse_block(&mut self) -> Option<StmtId>

Parse a block of statements

pub fn parse_statement(&mut self) -> Option<StmtId>

Parse a single statement